@@ -270,6 +270,8 @@ def inputModeNum(prompt, screenSurf, x, y, fgcol, bgcol, maxlen=12, pos='left',
                         translatedChar = _NUMBER_MAPPINGS.get(event.key, None)
                         if translatedChar is not None:
                             inputText += pygame_utils.toProperCase(translatedChar, event.mod)
+    if inputText.startswith("."):
+        inputText = "0" + inputText
     return inputText
 
 
@@ -585,7 +587,7 @@ def showSettingsScreen(screenSurf):
     pygame.display.update()
 
     while choice is None:
-        choice = inputMode("Your Choice?  ", screenSurf, SCR_WIDTH / 2 - 55, 260, GRAY_COLOR, BLACK_COLOR, maxlen=1, allowed='vp', pos='left', cursorBlink=True)
+        choice = inputMode("Your Choice?  ", screenSurf, SCR_WIDTH / 2 - 55, 290, GRAY_COLOR, BLACK_COLOR, maxlen=1, allowed='vp', pos='left', cursorBlink=True)
 
     return p1name, p2name, points, gravity, choice # returns 'v' or 'p'
 
